ExtraConfig

Struct ExtraConfig 

pub struct ExtraConfig {
Show 13 fields pub transcryptor_url: UrlPwa, pub auths_url: UrlPwa, pub global_client_url: UrlPwa, pub hubs: Vec<BasicInfo<UrlPwa>>, pub master_enc_key_part: Option<PrivateKey>, pub attr_id_secret: Option<B64UU>, pub auth_token_validity: Duration, pub pp_nonce_validity: Duration, pub card_pseud_validity: Duration, pub user_object_hmac_secret: Option<B64UU>, pub user_quota: Quota, pub card: Skip, pub hub_cache: HubCacheConfig,
}

Fields

transcryptor_url: UrlPwa

Where can we reach the transcryptor?

auths_url: UrlPwa

Where can we reach the authentication server?

global_client_url: UrlPwa

The URL to pubhubs used by end-clients.

Currently https://app.pubhubs.net for production, https://main.pubhubs.ihub.ru.nl for acceptance, and http://localhost:8080 for local development.

hubs: Vec<BasicInfo<UrlPwa>>

The hubs that are known to us

master_enc_key_part: Option<PrivateKey>

x_PHC from the whitepaper; randomly generated if not set

Generate using cargo run tools generate scalar.

attr_id_secret: Option<B64UU>

Secret used to derive Attr::ids.

Randomly generated if not set, which is not suitable for production.

auth_token_validity: Duration

Authentication tokens issued to the global client are valid for this duration.

Auth tokens are validated based on their own contents - there’s no list of valid authentication tokens in a database somewhere. This means that when a user is banned, the authentication tokens remain valid until they expire. The validity duration of auth tokens should thus not be too long.

pp_nonce_validity: Duration

api::phc::user::PpNonces issued to the global client are valid for this duration.

card_pseud_validity: Duration

Registration pseudonyms issued to the global client via api::phc::user::CardPseudEP are valid for this duration.

user_object_hmac_secret: Option<B64UU>

Secret used to derive hmacs for the retrieval of user objects.

Randomly generated if not set.

user_quota: Quota

Quotas for a user

card: Skip

Deprecated.

hub_cache: HubCacheConfig